"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MysqlConfig5_7(google.protobuf.message.Message):
    """Options and structure of `MysqlConfig5_7` reflects MySQL 5.7 configuration file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SQLMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SQLModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._SQLMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SQLMODE_UNSPECIFIED: MysqlConfig5_7._SQLMode.ValueType  # 0
        ALLOW_INVALID_DATES: MysqlConfig5_7._SQLMode.ValueType  # 1
        ANSI_QUOTES: MysqlConfig5_7._SQLMode.ValueType  # 2
        ERROR_FOR_DIVISION_BY_ZERO: MysqlConfig5_7._SQLMode.ValueType  # 3
        HIGH_NOT_PRECEDENCE: MysqlConfig5_7._SQLMode.ValueType  # 4
        IGNORE_SPACE: MysqlConfig5_7._SQLMode.ValueType  # 5
        NO_AUTO_VALUE_ON_ZERO: MysqlConfig5_7._SQLMode.ValueType  # 6
        NO_BACKSLASH_ESCAPES: MysqlConfig5_7._SQLMode.ValueType  # 7
        NO_ENGINE_SUBSTITUTION: MysqlConfig5_7._SQLMode.ValueType  # 8
        NO_UNSIGNED_SUBTRACTION: MysqlConfig5_7._SQLMode.ValueType  # 9
        NO_ZERO_DATE: MysqlConfig5_7._SQLMode.ValueType  # 10
        NO_ZERO_IN_DATE: MysqlConfig5_7._SQLMode.ValueType  # 11
        NO_FIELD_OPTIONS: MysqlConfig5_7._SQLMode.ValueType  # 12
        NO_KEY_OPTIONS: MysqlConfig5_7._SQLMode.ValueType  # 13
        NO_TABLE_OPTIONS: MysqlConfig5_7._SQLMode.ValueType  # 14
        ONLY_FULL_GROUP_BY: MysqlConfig5_7._SQLMode.ValueType  # 15
        PAD_CHAR_TO_FULL_LENGTH: MysqlConfig5_7._SQLMode.ValueType  # 16
        PIPES_AS_CONCAT: MysqlConfig5_7._SQLMode.ValueType  # 17
        REAL_AS_FLOAT: MysqlConfig5_7._SQLMode.ValueType  # 18
        STRICT_ALL_TABLES: MysqlConfig5_7._SQLMode.ValueType  # 19
        STRICT_TRANS_TABLES: MysqlConfig5_7._SQLMode.ValueType  # 20
        ANSI: MysqlConfig5_7._SQLMode.ValueType  # 21
        TRADITIONAL: MysqlConfig5_7._SQLMode.ValueType  # 22
        DB2: MysqlConfig5_7._SQLMode.ValueType  # 23
        MAXDB: MysqlConfig5_7._SQLMode.ValueType  # 24
        MSSQL: MysqlConfig5_7._SQLMode.ValueType  # 25
        MYSQL323: MysqlConfig5_7._SQLMode.ValueType  # 26
        MYSQL40: MysqlConfig5_7._SQLMode.ValueType  # 27
        ORACLE: MysqlConfig5_7._SQLMode.ValueType  # 28
        POSTGRESQL: MysqlConfig5_7._SQLMode.ValueType  # 29
        NO_AUTO_CREATE_USER: MysqlConfig5_7._SQLMode.ValueType  # 30
        NO_DIR_IN_CREATE: MysqlConfig5_7._SQLMode.ValueType  # 31

    class SQLMode(_SQLMode, metaclass=_SQLModeEnumTypeWrapper): ...
    SQLMODE_UNSPECIFIED: MysqlConfig5_7.SQLMode.ValueType  # 0
    ALLOW_INVALID_DATES: MysqlConfig5_7.SQLMode.ValueType  # 1
    ANSI_QUOTES: MysqlConfig5_7.SQLMode.ValueType  # 2
    ERROR_FOR_DIVISION_BY_ZERO: MysqlConfig5_7.SQLMode.ValueType  # 3
    HIGH_NOT_PRECEDENCE: MysqlConfig5_7.SQLMode.ValueType  # 4
    IGNORE_SPACE: MysqlConfig5_7.SQLMode.ValueType  # 5
    NO_AUTO_VALUE_ON_ZERO: MysqlConfig5_7.SQLMode.ValueType  # 6
    NO_BACKSLASH_ESCAPES: MysqlConfig5_7.SQLMode.ValueType  # 7
    NO_ENGINE_SUBSTITUTION: MysqlConfig5_7.SQLMode.ValueType  # 8
    NO_UNSIGNED_SUBTRACTION: MysqlConfig5_7.SQLMode.ValueType  # 9
    NO_ZERO_DATE: MysqlConfig5_7.SQLMode.ValueType  # 10
    NO_ZERO_IN_DATE: MysqlConfig5_7.SQLMode.ValueType  # 11
    NO_FIELD_OPTIONS: MysqlConfig5_7.SQLMode.ValueType  # 12
    NO_KEY_OPTIONS: MysqlConfig5_7.SQLMode.ValueType  # 13
    NO_TABLE_OPTIONS: MysqlConfig5_7.SQLMode.ValueType  # 14
    ONLY_FULL_GROUP_BY: MysqlConfig5_7.SQLMode.ValueType  # 15
    PAD_CHAR_TO_FULL_LENGTH: MysqlConfig5_7.SQLMode.ValueType  # 16
    PIPES_AS_CONCAT: MysqlConfig5_7.SQLMode.ValueType  # 17
    REAL_AS_FLOAT: MysqlConfig5_7.SQLMode.ValueType  # 18
    STRICT_ALL_TABLES: MysqlConfig5_7.SQLMode.ValueType  # 19
    STRICT_TRANS_TABLES: MysqlConfig5_7.SQLMode.ValueType  # 20
    ANSI: MysqlConfig5_7.SQLMode.ValueType  # 21
    TRADITIONAL: MysqlConfig5_7.SQLMode.ValueType  # 22
    DB2: MysqlConfig5_7.SQLMode.ValueType  # 23
    MAXDB: MysqlConfig5_7.SQLMode.ValueType  # 24
    MSSQL: MysqlConfig5_7.SQLMode.ValueType  # 25
    MYSQL323: MysqlConfig5_7.SQLMode.ValueType  # 26
    MYSQL40: MysqlConfig5_7.SQLMode.ValueType  # 27
    ORACLE: MysqlConfig5_7.SQLMode.ValueType  # 28
    POSTGRESQL: MysqlConfig5_7.SQLMode.ValueType  # 29
    NO_AUTO_CREATE_USER: MysqlConfig5_7.SQLMode.ValueType  # 30
    NO_DIR_IN_CREATE: MysqlConfig5_7.SQLMode.ValueType  # 31

    class _AuthPlugin:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AuthPluginEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._AuthPlugin.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUTH_PLUGIN_UNSPECIFIED: MysqlConfig5_7._AuthPlugin.ValueType  # 0
        MYSQL_NATIVE_PASSWORD: MysqlConfig5_7._AuthPlugin.ValueType  # 1
        """Using [Native Pluggable Authentication](https://dev.mysql.com/doc/refman/5.7/en/native-pluggable-authentication.html)."""
        CACHING_SHA2_PASSWORD: MysqlConfig5_7._AuthPlugin.ValueType  # 2
        SHA256_PASSWORD: MysqlConfig5_7._AuthPlugin.ValueType  # 3
        """Using [SHA-256 Pluggable Authentication](https://dev.mysql.com/doc/refman/5.7/en/sha256-pluggable-authentication.html)."""

    class AuthPlugin(_AuthPlugin, metaclass=_AuthPluginEnumTypeWrapper): ...
    AUTH_PLUGIN_UNSPECIFIED: MysqlConfig5_7.AuthPlugin.ValueType  # 0
    MYSQL_NATIVE_PASSWORD: MysqlConfig5_7.AuthPlugin.ValueType  # 1
    """Using [Native Pluggable Authentication](https://dev.mysql.com/doc/refman/5.7/en/native-pluggable-authentication.html)."""
    CACHING_SHA2_PASSWORD: MysqlConfig5_7.AuthPlugin.ValueType  # 2
    SHA256_PASSWORD: MysqlConfig5_7.AuthPlugin.ValueType  # 3
    """Using [SHA-256 Pluggable Authentication](https://dev.mysql.com/doc/refman/5.7/en/sha256-pluggable-authentication.html)."""

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: MysqlConfig5_7._TransactionIsolation.ValueType  # 0
        READ_COMMITTED: MysqlConfig5_7._TransactionIsolation.ValueType  # 1
        REPEATABLE_READ: MysqlConfig5_7._TransactionIsolation.ValueType  # 2
        SERIALIZABLE: MysqlConfig5_7._TransactionIsolation.ValueType  # 3

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: MysqlConfig5_7.TransactionIsolation.ValueType  # 0
    READ_COMMITTED: MysqlConfig5_7.TransactionIsolation.ValueType  # 1
    REPEATABLE_READ: MysqlConfig5_7.TransactionIsolation.ValueType  # 2
    SERIALIZABLE: MysqlConfig5_7.TransactionIsolation.ValueType  # 3

    class _BinlogRowImage:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BinlogRowImageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._BinlogRowImage.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BINLOG_ROW_IMAGE_UNSPECIFIED: MysqlConfig5_7._BinlogRowImage.ValueType  # 0
        FULL: MysqlConfig5_7._BinlogRowImage.ValueType  # 1
        MINIMAL: MysqlConfig5_7._BinlogRowImage.ValueType  # 2
        NOBLOB: MysqlConfig5_7._BinlogRowImage.ValueType  # 3

    class BinlogRowImage(_BinlogRowImage, metaclass=_BinlogRowImageEnumTypeWrapper): ...
    BINLOG_ROW_IMAGE_UNSPECIFIED: MysqlConfig5_7.BinlogRowImage.ValueType  # 0
    FULL: MysqlConfig5_7.BinlogRowImage.ValueType  # 1
    MINIMAL: MysqlConfig5_7.BinlogRowImage.ValueType  # 2
    NOBLOB: MysqlConfig5_7.BinlogRowImage.ValueType  # 3

    class _SlaveParallelType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SlaveParallelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._SlaveParallelType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SLAVE_PARALLEL_TYPE_UNSPECIFIED: MysqlConfig5_7._SlaveParallelType.ValueType  # 0
        DATABASE: MysqlConfig5_7._SlaveParallelType.ValueType  # 1
        LOGICAL_CLOCK: MysqlConfig5_7._SlaveParallelType.ValueType  # 2

    class SlaveParallelType(_SlaveParallelType, metaclass=_SlaveParallelTypeEnumTypeWrapper): ...
    SLAVE_PARALLEL_TYPE_UNSPECIFIED: MysqlConfig5_7.SlaveParallelType.ValueType  # 0
    DATABASE: MysqlConfig5_7.SlaveParallelType.ValueType  # 1
    LOGICAL_CLOCK: MysqlConfig5_7.SlaveParallelType.ValueType  # 2

    class _LogSlowRateType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogSlowRateTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._LogSlowRateType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_SLOW_RATE_TYPE_UNSPECIFIED: MysqlConfig5_7._LogSlowRateType.ValueType  # 0
        SESSION: MysqlConfig5_7._LogSlowRateType.ValueType  # 1
        QUERY: MysqlConfig5_7._LogSlowRateType.ValueType  # 2

    class LogSlowRateType(_LogSlowRateType, metaclass=_LogSlowRateTypeEnumTypeWrapper): ...
    LOG_SLOW_RATE_TYPE_UNSPECIFIED: MysqlConfig5_7.LogSlowRateType.ValueType  # 0
    SESSION: MysqlConfig5_7.LogSlowRateType.ValueType  # 1
    QUERY: MysqlConfig5_7.LogSlowRateType.ValueType  # 2

    class _LogSlowFilterType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogSlowFilterTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._LogSlowFilterType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_SLOW_FILTER_TYPE_UNSPECIFIED: MysqlConfig5_7._LogSlowFilterType.ValueType  # 0
        FULL_SCAN: MysqlConfig5_7._LogSlowFilterType.ValueType  # 1
        FULL_JOIN: MysqlConfig5_7._LogSlowFilterType.ValueType  # 2
        TMP_TABLE: MysqlConfig5_7._LogSlowFilterType.ValueType  # 3
        TMP_TABLE_ON_DISK: MysqlConfig5_7._LogSlowFilterType.ValueType  # 4
        FILESORT: MysqlConfig5_7._LogSlowFilterType.ValueType  # 5
        FILESORT_ON_DISK: MysqlConfig5_7._LogSlowFilterType.ValueType  # 6

    class LogSlowFilterType(_LogSlowFilterType, metaclass=_LogSlowFilterTypeEnumTypeWrapper): ...
    LOG_SLOW_FILTER_TYPE_UNSPECIFIED: MysqlConfig5_7.LogSlowFilterType.ValueType  # 0
    FULL_SCAN: MysqlConfig5_7.LogSlowFilterType.ValueType  # 1
    FULL_JOIN: MysqlConfig5_7.LogSlowFilterType.ValueType  # 2
    TMP_TABLE: MysqlConfig5_7.LogSlowFilterType.ValueType  # 3
    TMP_TABLE_ON_DISK: MysqlConfig5_7.LogSlowFilterType.ValueType  # 4
    FILESORT: MysqlConfig5_7.LogSlowFilterType.ValueType  # 5
    FILESORT_ON_DISK: MysqlConfig5_7.LogSlowFilterType.ValueType  # 6

    class _BinlogTransactionDependencyTracking:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BinlogTransactionDependencyTrackingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MysqlConfig5_7._BinlogTransactionDependencyTracking.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BINLOG_TRANSACTION_DEPENDENCY_TRACKING_UNSPECIFIED: MysqlConfig5_7._BinlogTransactionDependencyTracking.ValueType  # 0
        COMMIT_ORDER: MysqlConfig5_7._BinlogTransactionDependencyTracking.ValueType  # 1
        WRITESET: MysqlConfig5_7._BinlogTransactionDependencyTracking.ValueType  # 2
        WRITESET_SESSION: MysqlConfig5_7._BinlogTransactionDependencyTracking.ValueType  # 3

    class BinlogTransactionDependencyTracking(_BinlogTransactionDependencyTracking, metaclass=_BinlogTransactionDependencyTrackingEnumTypeWrapper): ...
    BINLOG_TRANSACTION_DEPENDENCY_TRACKING_UNSPECIFIED: MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType  # 0
    COMMIT_ORDER: MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType  # 1
    WRITESET: MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType  # 2
    WRITESET_SESSION: MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType  # 3

    INNODB_BUFFER_POOL_SIZE_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    LONG_QUERY_TIME_FIELD_NUMBER: builtins.int
    GENERAL_LOG_FIELD_NUMBER: builtins.int
    AUDIT_LOG_FIELD_NUMBER: builtins.int
    SQL_MODE_FIELD_NUMBER: builtins.int
    MAX_ALLOWED_PACKET_FIELD_NUMBER: builtins.int
    DEFAULT_AUTHENTICATION_PLUGIN_FIELD_NUMBER: builtins.int
    INNODB_FLUSH_LOG_AT_TRX_COMMIT_FIELD_NUMBER: builtins.int
    INNODB_LOCK_WAIT_TIMEOUT_FIELD_NUMBER: builtins.int
    TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    INNODB_PRINT_ALL_DEADLOCKS_FIELD_NUMBER: builtins.int
    NET_READ_TIMEOUT_FIELD_NUMBER: builtins.int
    NET_WRITE_TIMEOUT_FIELD_NUMBER: builtins.int
    GROUP_CONCAT_MAX_LEN_FIELD_NUMBER: builtins.int
    TMP_TABLE_SIZE_FIELD_NUMBER: builtins.int
    MAX_HEAP_TABLE_SIZE_FIELD_NUMBER: builtins.int
    DEFAULT_TIME_ZONE_FIELD_NUMBER: builtins.int
    CHARACTER_SET_SERVER_FIELD_NUMBER: builtins.int
    COLLATION_SERVER_FIELD_NUMBER: builtins.int
    INNODB_ADAPTIVE_HASH_INDEX_FIELD_NUMBER: builtins.int
    INNODB_NUMA_INTERLEAVE_FIELD_NUMBER: builtins.int
    INNODB_LOG_BUFFER_SIZE_FIELD_NUMBER: builtins.int
    INNODB_LOG_FILE_SIZE_FIELD_NUMBER: builtins.int
    INNODB_IO_CAPACITY_FIELD_NUMBER: builtins.int
    INNODB_IO_CAPACITY_MAX_FIELD_NUMBER: builtins.int
    INNODB_READ_IO_THREADS_FIELD_NUMBER: builtins.int
    INNODB_WRITE_IO_THREADS_FIELD_NUMBER: builtins.int
    INNODB_PURGE_THREADS_FIELD_NUMBER: builtins.int
    INNODB_THREAD_CONCURRENCY_FIELD_NUMBER: builtins.int
    INNODB_TEMP_DATA_FILE_MAX_SIZE_FIELD_NUMBER: builtins.int
    THREAD_CACHE_SIZE_FIELD_NUMBER: builtins.int
    THREAD_STACK_FIELD_NUMBER: builtins.int
    JOIN_BUFFER_SIZE_FIELD_NUMBER: builtins.int
    SORT_BUFFER_SIZE_FIELD_NUMBER: builtins.int
    TABLE_DEFINITION_CACHE_FIELD_NUMBER: builtins.int
    TABLE_OPEN_CACHE_FIELD_NUMBER: builtins.int
    TABLE_OPEN_CACHE_INSTANCES_FIELD_NUMBER: builtins.int
    EXPLICIT_DEFAULTS_FOR_TIMESTAMP_FIELD_NUMBER: builtins.int
    AUTO_INCREMENT_INCREMENT_FIELD_NUMBER: builtins.int
    AUTO_INCREMENT_OFFSET_FIELD_NUMBER: builtins.int
    SYNC_BINLOG_FIELD_NUMBER: builtins.int
    BINLOG_CACHE_SIZE_FIELD_NUMBER: builtins.int
    BINLOG_GROUP_COMMIT_SYNC_DELAY_FIELD_NUMBER: builtins.int
    BINLOG_ROW_IMAGE_FIELD_NUMBER: builtins.int
    BINLOG_ROWS_QUERY_LOG_EVENTS_FIELD_NUMBER: builtins.int
    RPL_SEMI_SYNC_MASTER_WAIT_FOR_SLAVE_COUNT_FIELD_NUMBER: builtins.int
    SLAVE_PARALLEL_TYPE_FIELD_NUMBER: builtins.int
    SLAVE_PARALLEL_WORKERS_FIELD_NUMBER: builtins.int
    MDB_PRESERVE_BINLOG_BYTES_FIELD_NUMBER: builtins.int
    INTERACTIVE_TIMEOUT_FIELD_NUMBER: builtins.int
    WAIT_TIMEOUT_FIELD_NUMBER: builtins.int
    MDB_OFFLINE_MODE_ENABLE_LAG_FIELD_NUMBER: builtins.int
    MDB_OFFLINE_MODE_DISABLE_LAG_FIELD_NUMBER: builtins.int
    RANGE_OPTIMIZER_MAX_MEM_SIZE_FIELD_NUMBER: builtins.int
    SLOW_QUERY_LOG_FIELD_NUMBER: builtins.int
    SLOW_QUERY_LOG_ALWAYS_WRITE_TIME_FIELD_NUMBER: builtins.int
    LOG_SLOW_RATE_TYPE_FIELD_NUMBER: builtins.int
    LOG_SLOW_RATE_LIMIT_FIELD_NUMBER: builtins.int
    LOG_SLOW_SP_STATEMENTS_FIELD_NUMBER: builtins.int
    LOG_SLOW_FILTER_FIELD_NUMBER: builtins.int
    MDB_PRIORITY_CHOICE_MAX_LAG_FIELD_NUMBER: builtins.int
    INNODB_PAGE_SIZE_FIELD_NUMBER: builtins.int
    INNODB_ONLINE_ALTER_LOG_MAX_SIZE_FIELD_NUMBER: builtins.int
    INNODB_FT_MIN_TOKEN_SIZE_FIELD_NUMBER: builtins.int
    INNODB_FT_MAX_TOKEN_SIZE_FIELD_NUMBER: builtins.int
    LOWER_CASE_TABLE_NAMES_FIELD_NUMBER: builtins.int
    SHOW_COMPATIBILITY_56_FIELD_NUMBER: builtins.int
    MAX_SP_RECURSION_DEPTH_FIELD_NUMBER: builtins.int
    INNODB_COMPRESSION_LEVEL_FIELD_NUMBER: builtins.int
    BINLOG_TRANSACTION_DEPENDENCY_TRACKING_FIELD_NUMBER: builtins.int
    AUTOCOMMIT_FIELD_NUMBER: builtins.int
    INNODB_STATUS_OUTPUT_FIELD_NUMBER: builtins.int
    INNODB_STRICT_MODE_FIELD_NUMBER: builtins.int
    INNODB_PRINT_LOCK_WAIT_TIMEOUT_INFO_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    MAX_DIGEST_LENGTH_FIELD_NUMBER: builtins.int
    QUERY_CACHE_LIMIT_FIELD_NUMBER: builtins.int
    QUERY_CACHE_SIZE_FIELD_NUMBER: builtins.int
    QUERY_CACHE_TYPE_FIELD_NUMBER: builtins.int
    LOCK_WAIT_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_PREPARED_STMT_COUNT_FIELD_NUMBER: builtins.int
    OPTIMIZER_SWITCH_FIELD_NUMBER: builtins.int
    OPTIMIZER_SEARCH_DEPTH_FIELD_NUMBER: builtins.int
    QUERY_RESPONSE_TIME_STATS_FIELD_NUMBER: builtins.int
    USERSTAT_FIELD_NUMBER: builtins.int
    MAX_EXECUTION_TIME_FIELD_NUMBER: builtins.int
    default_authentication_plugin: global___MysqlConfig5_7.AuthPlugin.ValueType
    """Authentication plugin used in the managed MySQL cluster.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_default_authentication_plugin) for details.
    """
    transaction_isolation: global___MysqlConfig5_7.TransactionIsolation.ValueType
    """Default transaction isolation level.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_transaction_isolation) for details.
    """
    default_time_zone: builtins.str
    """The servers default time zone.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-options.html#option_mysqld_default-time-zone) for details.
    """
    character_set_server: builtins.str
    """The servers default character set.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_character_set_server) for details.
    """
    collation_server: builtins.str
    """The server default collation.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_collation_server) for details.
    """
    binlog_row_image: global___MysqlConfig5_7.BinlogRowImage.ValueType
    """For MySQL row-based replication, this variable determines how row images are written to the binary log.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_row_image) for details.
    """
    slave_parallel_type: global___MysqlConfig5_7.SlaveParallelType.ValueType
    """When using a multi-threaded replica, this variable specifies the policy used to decide which transactions are allowed to execute in parallel on the replica.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-replica.html#sysvar_slave_parallel_type) for details.
    """
    log_slow_rate_type: global___MysqlConfig5_7.LogSlowRateType.ValueType
    """Specifies slow log granularity for `log_slow_rate_limit` values QUERY or SESSION.

    See [Percona documentation](https://www.percona.com/doc/percona-server/8.0/diagnostics/slow_extended.html#log_slow_rate_type) for details.
    """
    binlog_transaction_dependency_tracking: global___MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType
    """Specifies how the source mysqld generates the dependency information that it writes in the binary log to help replicas determine which transactions can be executed in parallel.

    For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_transaction_dependency_tracking).
    """
    optimizer_switch: builtins.str
    """The system variable enables control over optimizer behavior.

    For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_optimizer_switch)
    https://dev.mysql.com/doc/refman/5.7/en/switchable-optimizations.html
    """
    @property
    def innodb_buffer_pool_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Size of the InnoDB buffer pool used for caching table and index data.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_buffer_pool_size) for details.
        """

    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted number of simultaneous client connections.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_connections) for details.
        """

    @property
    def long_query_time(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Time that it takes to process a query before it is considered slow.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_long_query_time) for details.
        """

    @property
    def general_log(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable writing of general query log of MySQL.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_general_log) for details.
        """

    @property
    def audit_log(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable writing of audit log of MySQL.

        See [MySQL documentation](https://dev.mysql.com/doc/mysql-security-excerpt/5.7/en/audit-log-reference.html#audit-log-options-variables) for details.
        """

    @property
    def sql_mode(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___MysqlConfig5_7.SQLMode.ValueType]:
        """Server SQL mode of MySQL.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/sql-mode.html#sql-mode-setting) for details.
        """

    @property
    def max_allowed_packet(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size in bytes of one packet.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_allowed_packet) for details.
        """

    @property
    def innodb_flush_log_at_trx_commit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Transaction log flush behaviour.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_flush_log_at_trx_commit) for details.
        """

    @property
    def innodb_lock_wait_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time in seconds for a transaction to wait for a row lock.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_lock_wait_timeout) for details.
        """

    @property
    def innodb_print_all_deadlocks(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Print information about deadlocks in error log.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_print_all_deadlocks) for details.
        """

    @property
    def net_read_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of seconds to wait for more data from a connection before aborting the read.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_net_read_timeout) for details.
        """

    @property
    def net_write_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of seconds to wait for a block to be written to a connection before aborting the write.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_net_write_timeout) for details.
        """

    @property
    def group_concat_max_len(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted result length in bytes for the GROUP_CONCAT() function.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_group_concat_max_len) for details.
        """

    @property
    def tmp_table_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size of internal in-memory temporary tables.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_tmp_table_size) for details.
        """

    @property
    def max_heap_table_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This variable sets the maximum size to which user-created MEMORY tables are permitted to grow.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_heap_table_size) for details.
        """

    @property
    def innodb_adaptive_hash_index(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables InnoDB adaptive hash index.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_adaptive_hash_index) for details.
        """

    @property
    def innodb_numa_interleave(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables the NUMA interleave memory policy for allocation of the InnoDB buffer pool.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_numa_interleave) for details.
        """

    @property
    def innodb_log_buffer_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The size in bytes of the buffer that InnoDB uses to write to the log files on disk.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_log_buffer_size) for details.
        """

    @property
    def innodb_log_file_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The size in bytes of the single InnoDB Redo log file.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_log_file_size) for details.
        """

    @property
    def innodb_io_capacity(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Limits IO available for InnoDB background tasks.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_io_capacity) for details.
        """

    @property
    def innodb_io_capacity_max(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Limits IO available for InnoDB background tasks.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_io_capacity_max) for details.
        """

    @property
    def innodb_read_io_threads(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of I/O threads for read operations in InnoDB.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_read_io_threads) for details.
        """

    @property
    def innodb_write_io_threads(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of I/O threads for write operations in InnoDB.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_write_io_threads) for details.
        """

    @property
    def innodb_purge_threads(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of background threads devoted to the InnoDB purge operation.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_purge_threads) for details.
        """

    @property
    def innodb_thread_concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Defines the maximum number of threads permitted inside of InnoDB.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_thread_concurrency) for details.
        """

    @property
    def innodb_temp_data_file_max_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Limits the max size of InnoDB temp tablespace.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_temp_data_file_path) for details.
        """

    @property
    def thread_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """A number of threads the server should cache for reuse.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_thread_cache_size) for details.
        """

    @property
    def thread_stack(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The stack size for each thread. The default is large enough for normal operation.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_thread_stack) for details.
        """

    @property
    def join_buffer_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The minimum size of the buffer that is used for plain index scans, range index scans, and joins that do not use indexes and thus perform full table scans.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_join_buffer_size) for details.
        """

    @property
    def sort_buffer_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Each session that must perform a sort allocates a buffer of this size.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_sort_buffer_size) for details.
        """

    @property
    def table_definition_cache(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of table definitions that can be stored in the definition cache.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_table_definition_cache) for details.
        """

    @property
    def table_open_cache(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of open tables for all threads.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_table_open_cache) for details.
        """

    @property
    def table_open_cache_instances(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of open tables cache instances.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_table_open_cache_instances) for details.
        """

    @property
    def explicit_defaults_for_timestamp(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the server enables certain nonstandard behaviors for default values and NULL-value handling in TIMESTAMP columns.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_explicit_defaults_for_timestamp) for details.
        """

    @property
    def auto_increment_increment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Can be used to control the operation of AUTO_INCREMENT columns.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-source.html#sysvar_auto_increment_increment) for details.
        """

    @property
    def auto_increment_offset(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Can be used to control the operation of AUTO_INCREMENT columns.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-source.html#sysvar_auto_increment_offset) for details.
        """

    @property
    def sync_binlog(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Controls how often the MySQL server synchronizes the binary log to disk.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_sync_binlog) for details.
        """

    @property
    def binlog_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The size of the cache to hold changes to the binary log during a transaction.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_cache_size) for details.
        """

    @property
    def binlog_group_commit_sync_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Controls how many microseconds the binary log commit waits before synchronizing the binary log file to disk.

        See [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_group_commit_sync_delay) for details.
        """

    @property
    def binlog_rows_query_log_events(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """When enabled, it causes the server to write informational log events such as row query log events into its binary log.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-binary-log.html#sysvar_binlog_rows_query_log_events) for details.
        """

    @property
    def rpl_semi_sync_master_wait_for_slave_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of replica acknowledgments the source must receive per transaction before proceeding.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-source.html#sysvar_rpl_semi_sync_master_wait_for_slave_count) for details.
        """

    @property
    def slave_parallel_workers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the number of applier threads for executing replication transactions in parallel.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/replication-options-replica.html#sysvar_slave_parallel_workers) for details.
        """

    @property
    def mdb_preserve_binlog_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The size of the binary log to hold."""

    @property
    def interactive_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of seconds the server waits for activity on an interactive connection before closing it.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_interactive_timeout) for details.
        """

    @property
    def wait_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of seconds the server waits for activity on a noninteractive connection before closing it.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_wait_timeout) for details.
        """

    @property
    def mdb_offline_mode_enable_lag(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication lag threshold (seconds) which will switch MySQL to 'offline_mode = ON' to prevent users from reading stale data."""

    @property
    def mdb_offline_mode_disable_lag(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication lag threshold (seconds) which will switch MySQL to 'offline_mode = OFF'.
        Should be less than mdb_offline_mode_enable_lag value.
        """

    @property
    def range_optimizer_max_mem_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on memory consumption for the range optimizer.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_range_optimizer_max_mem_size) for details.
        """

    @property
    def slow_query_log(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Manages slow query log.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/8.0/en/server-system-variables.html#sysvar_slow_query_log) for details.
        """

    @property
    def slow_query_log_always_write_time(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Query execution time, after which query to be logged unconditionally, that is, `log_slow_rate_limit`` will not apply to it.

        See [Percona documentation](https://www.percona.com/doc/percona-server/8.0/diagnostics/slow_extended.html#slow_query_log_always_write_time) for details.
        """

    @property
    def log_slow_rate_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies what fraction of session/query should be logged. Logging is enabled for every nth session/query.

        See [Percona documentation](https://www.percona.com/doc/percona-server/8.0/diagnostics/slow_extended.html#log_slow_rate_limit) for details.
        """

    @property
    def log_slow_sp_statements(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """When TRUE, statements executed by stored procedures are logged to the slow log.

        See [Percona documentation](https://www.percona.com/doc/percona-server/8.0/diagnostics/slow_extended.html#log_slow_sp_statements) for details.
        """

    @property
    def log_slow_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___MysqlConfig5_7.LogSlowFilterType.ValueType]:
        """Filters the slow log by the query's execution plan.

        See [Percona documentation](https://www.percona.com/doc/percona-server/8.0/diagnostics/slow_extended.html#log_slow_filter) for details.
        """

    @property
    def mdb_priority_choice_max_lag(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication lag threshold (seconds) which allows replica to be promoted to master while executing "switchover from".
        Should be less than mdb_offline_mode_disable_lag.
        """

    @property
    def innodb_page_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the page size for InnoDB tablespaces.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_page_size).
        """

    @property
    def innodb_online_alter_log_max_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit in bytes on the size of the temporary log files used during online DDL operations

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_online_alter_log_max_size).
        """

    @property
    def innodb_ft_min_token_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Minimum length of words that are stored in an InnoDB FULLTEXT index

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_ft_min_token_size).
        """

    @property
    def innodb_ft_max_token_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum length of words that are stored in an InnoDB FULLTEXT index

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_ft_max_token_size).
        """

    @property
    def lower_case_table_names(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Table names storage and comparison strategy

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_lower_case_table_names).
        """

    @property
    def show_compatibility_56(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Manages MySQL 5.6 compatibility

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_show_compatibility_56).
        """

    @property
    def max_sp_recursion_depth(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of times that any given stored procedure may be called recursively.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_sp_recursion_depth).
        """

    @property
    def innodb_compression_level(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The level of zlib compression to use for InnoDB compressed tables and indexes.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_compression_level).
        """

    @property
    def autocommit(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Config specific will be all changes to a table take effect immediately or you must use COMMIT to accept a transaction or ROLLBACK to cancel it.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_autocommit).
        """

    @property
    def innodb_status_output(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables or disables periodic output for the standard InnoDB Monitor.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_status_output).
        """

    @property
    def innodb_strict_mode(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """When innodb_strict_mode is enabled, InnoDB returns errors rather than warnings when checking for invalid or incompatible table options.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_strict_mode).
        """

    @property
    def innodb_print_lock_wait_timeout_info(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Makes InnoDB to write information about all lock wait timeout errors into the log file.

        For details, see [Percona documentation for the variable](https://docs.percona.com/percona-server/5.7/diagnostics/innodb_show_status.html?highlight=innodb_print_lock_wait_timeout_info).
        """

    @property
    def log_error_verbosity(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """System variable specifies the verbosity for handling events intended for the error log

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_log_error_verbosity).
        """

    @property
    def max_digest_length(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of bytes of memory reserved per session for computation of normalized statement digests.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_digest_length).
        """

    @property
    def query_cache_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Do not cache results that are larger than this number of bytes.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_query_cache_limit).
        """

    @property
    def query_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The amount of memory allocated for caching query results.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_query_cache_size).
        """

    @property
    def query_cache_type(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Set the query cache type.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_query_cache_type).
        """

    @property
    def lock_wait_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """// This variable specifies the timeout in seconds for attempts to acquire metadata locks

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_lock_wait_timeout).
        """

    @property
    def max_prepared_stmt_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This variable limits the total number of prepared statements in the server.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_prepared_stmt_count).
        """

    @property
    def optimizer_search_depth(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum depth of search performed by the query optimizer

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html)
        """

    @property
    def query_response_time_stats(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables and disables collection of query times

        For details, see [Percona documentation for the variable](https://docs.percona.com/percona-server/5.7/diagnostics/response_time_distribution.html#query_response_time_stats).
        """

    @property
    def userstat(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables or disables collection of statistics

        For details, see [Percona documentation for the variable](https://docs.percona.com/percona-server/5.7/diagnostics/user_stats.html#userstat).
        """

    @property
    def max_execution_time(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The execution timeout for SELECT statements, in milliseconds. If the value is 0, timeouts are not enabled.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_execution_time)
        """

    def __init__(
        self,
        *,
        innodb_buffer_pool_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        long_query_time: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        general_log: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        audit_log: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        sql_mode: collections.abc.Iterable[global___MysqlConfig5_7.SQLMode.ValueType] | None = ...,
        max_allowed_packet: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_authentication_plugin: global___MysqlConfig5_7.AuthPlugin.ValueType = ...,
        innodb_flush_log_at_trx_commit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_lock_wait_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        transaction_isolation: global___MysqlConfig5_7.TransactionIsolation.ValueType = ...,
        innodb_print_all_deadlocks: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        net_read_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        net_write_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        group_concat_max_len: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        tmp_table_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_heap_table_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_time_zone: builtins.str = ...,
        character_set_server: builtins.str = ...,
        collation_server: builtins.str = ...,
        innodb_adaptive_hash_index: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        innodb_numa_interleave: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        innodb_log_buffer_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_log_file_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_io_capacity: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_io_capacity_max: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_read_io_threads: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_write_io_threads: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_purge_threads: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_thread_concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_temp_data_file_max_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        thread_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        thread_stack: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        join_buffer_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        sort_buffer_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        table_definition_cache: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        table_open_cache: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        table_open_cache_instances: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        explicit_defaults_for_timestamp: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        auto_increment_increment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_increment_offset: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        sync_binlog: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        binlog_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        binlog_group_commit_sync_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        binlog_row_image: global___MysqlConfig5_7.BinlogRowImage.ValueType = ...,
        binlog_rows_query_log_events: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        rpl_semi_sync_master_wait_for_slave_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        slave_parallel_type: global___MysqlConfig5_7.SlaveParallelType.ValueType = ...,
        slave_parallel_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        mdb_preserve_binlog_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        interactive_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        wait_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        mdb_offline_mode_enable_lag: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        mdb_offline_mode_disable_lag: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        range_optimizer_max_mem_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        slow_query_log: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        slow_query_log_always_write_time: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_slow_rate_type: global___MysqlConfig5_7.LogSlowRateType.ValueType = ...,
        log_slow_rate_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_slow_sp_statements: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_slow_filter: collections.abc.Iterable[global___MysqlConfig5_7.LogSlowFilterType.ValueType] | None = ...,
        mdb_priority_choice_max_lag: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_page_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_online_alter_log_max_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_ft_min_token_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_ft_max_token_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lower_case_table_names: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        show_compatibility_56: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_sp_recursion_depth: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        innodb_compression_level: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        binlog_transaction_dependency_tracking: global___MysqlConfig5_7.BinlogTransactionDependencyTracking.ValueType = ...,
        autocommit: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        innodb_status_output: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        innodb_strict_mode: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        innodb_print_lock_wait_timeout_info: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_error_verbosity: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_digest_length: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        query_cache_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        query_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        query_cache_type: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_wait_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_stmt_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        optimizer_switch: builtins.str = ...,
        optimizer_search_depth: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        query_response_time_stats: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        userstat: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_execution_time: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audit_log", b"audit_log", "auto_increment_increment", b"auto_increment_increment", "auto_increment_offset", b"auto_increment_offset", "autocommit", b"autocommit", "binlog_cache_size", b"binlog_cache_size", "binlog_group_commit_sync_delay", b"binlog_group_commit_sync_delay", "binlog_rows_query_log_events", b"binlog_rows_query_log_events", "explicit_defaults_for_timestamp", b"explicit_defaults_for_timestamp", "general_log", b"general_log", "group_concat_max_len", b"group_concat_max_len", "innodb_adaptive_hash_index", b"innodb_adaptive_hash_index", "innodb_buffer_pool_size", b"innodb_buffer_pool_size", "innodb_compression_level", b"innodb_compression_level", "innodb_flush_log_at_trx_commit", b"innodb_flush_log_at_trx_commit", "innodb_ft_max_token_size", b"innodb_ft_max_token_size", "innodb_ft_min_token_size", b"innodb_ft_min_token_size", "innodb_io_capacity", b"innodb_io_capacity", "innodb_io_capacity_max", b"innodb_io_capacity_max", "innodb_lock_wait_timeout", b"innodb_lock_wait_timeout", "innodb_log_buffer_size", b"innodb_log_buffer_size", "innodb_log_file_size", b"innodb_log_file_size", "innodb_numa_interleave", b"innodb_numa_interleave", "innodb_online_alter_log_max_size", b"innodb_online_alter_log_max_size", "innodb_page_size", b"innodb_page_size", "innodb_print_all_deadlocks", b"innodb_print_all_deadlocks", "innodb_print_lock_wait_timeout_info", b"innodb_print_lock_wait_timeout_info", "innodb_purge_threads", b"innodb_purge_threads", "innodb_read_io_threads", b"innodb_read_io_threads", "innodb_status_output", b"innodb_status_output", "innodb_strict_mode", b"innodb_strict_mode", "innodb_temp_data_file_max_size", b"innodb_temp_data_file_max_size", "innodb_thread_concurrency", b"innodb_thread_concurrency", "innodb_write_io_threads", b"innodb_write_io_threads", "interactive_timeout", b"interactive_timeout", "join_buffer_size", b"join_buffer_size", "lock_wait_timeout", b"lock_wait_timeout", "log_error_verbosity", b"log_error_verbosity", "log_slow_rate_limit", b"log_slow_rate_limit", "log_slow_sp_statements", b"log_slow_sp_statements", "long_query_time", b"long_query_time", "lower_case_table_names", b"lower_case_table_names", "max_allowed_packet", b"max_allowed_packet", "max_connections", b"max_connections", "max_digest_length", b"max_digest_length", "max_execution_time", b"max_execution_time", "max_heap_table_size", b"max_heap_table_size", "max_prepared_stmt_count", b"max_prepared_stmt_count", "max_sp_recursion_depth", b"max_sp_recursion_depth", "mdb_offline_mode_disable_lag", b"mdb_offline_mode_disable_lag", "mdb_offline_mode_enable_lag", b"mdb_offline_mode_enable_lag", "mdb_preserve_binlog_bytes", b"mdb_preserve_binlog_bytes", "mdb_priority_choice_max_lag", b"mdb_priority_choice_max_lag", "net_read_timeout", b"net_read_timeout", "net_write_timeout", b"net_write_timeout", "optimizer_search_depth", b"optimizer_search_depth", "query_cache_limit", b"query_cache_limit", "query_cache_size", b"query_cache_size", "query_cache_type", b"query_cache_type", "query_response_time_stats", b"query_response_time_stats", "range_optimizer_max_mem_size", b"range_optimizer_max_mem_size", "rpl_semi_sync_master_wait_for_slave_count", b"rpl_semi_sync_master_wait_for_slave_count", "show_compatibility_56", b"show_compatibility_56", "slave_parallel_workers", b"slave_parallel_workers", "slow_query_log", b"slow_query_log", "slow_query_log_always_write_time", b"slow_query_log_always_write_time", "sort_buffer_size", b"sort_buffer_size", "sync_binlog", b"sync_binlog", "table_definition_cache", b"table_definition_cache", "table_open_cache", b"table_open_cache", "table_open_cache_instances", b"table_open_cache_instances", "thread_cache_size", b"thread_cache_size", "thread_stack", b"thread_stack", "tmp_table_size", b"tmp_table_size", "userstat", b"userstat", "wait_timeout", b"wait_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_log", b"audit_log", "auto_increment_increment", b"auto_increment_increment", "auto_increment_offset", b"auto_increment_offset", "autocommit", b"autocommit", "binlog_cache_size", b"binlog_cache_size", "binlog_group_commit_sync_delay", b"binlog_group_commit_sync_delay", "binlog_row_image", b"binlog_row_image", "binlog_rows_query_log_events", b"binlog_rows_query_log_events", "binlog_transaction_dependency_tracking", b"binlog_transaction_dependency_tracking", "character_set_server", b"character_set_server", "collation_server", b"collation_server", "default_authentication_plugin", b"default_authentication_plugin", "default_time_zone", b"default_time_zone", "explicit_defaults_for_timestamp", b"explicit_defaults_for_timestamp", "general_log", b"general_log", "group_concat_max_len", b"group_concat_max_len", "innodb_adaptive_hash_index", b"innodb_adaptive_hash_index", "innodb_buffer_pool_size", b"innodb_buffer_pool_size", "innodb_compression_level", b"innodb_compression_level", "innodb_flush_log_at_trx_commit", b"innodb_flush_log_at_trx_commit", "innodb_ft_max_token_size", b"innodb_ft_max_token_size", "innodb_ft_min_token_size", b"innodb_ft_min_token_size", "innodb_io_capacity", b"innodb_io_capacity", "innodb_io_capacity_max", b"innodb_io_capacity_max", "innodb_lock_wait_timeout", b"innodb_lock_wait_timeout", "innodb_log_buffer_size", b"innodb_log_buffer_size", "innodb_log_file_size", b"innodb_log_file_size", "innodb_numa_interleave", b"innodb_numa_interleave", "innodb_online_alter_log_max_size", b"innodb_online_alter_log_max_size", "innodb_page_size", b"innodb_page_size", "innodb_print_all_deadlocks", b"innodb_print_all_deadlocks", "innodb_print_lock_wait_timeout_info", b"innodb_print_lock_wait_timeout_info", "innodb_purge_threads", b"innodb_purge_threads", "innodb_read_io_threads", b"innodb_read_io_threads", "innodb_status_output", b"innodb_status_output", "innodb_strict_mode", b"innodb_strict_mode", "innodb_temp_data_file_max_size", b"innodb_temp_data_file_max_size", "innodb_thread_concurrency", b"innodb_thread_concurrency", "innodb_write_io_threads", b"innodb_write_io_threads", "interactive_timeout", b"interactive_timeout", "join_buffer_size", b"join_buffer_size", "lock_wait_timeout", b"lock_wait_timeout", "log_error_verbosity", b"log_error_verbosity", "log_slow_filter", b"log_slow_filter", "log_slow_rate_limit", b"log_slow_rate_limit", "log_slow_rate_type", b"log_slow_rate_type", "log_slow_sp_statements", b"log_slow_sp_statements", "long_query_time", b"long_query_time", "lower_case_table_names", b"lower_case_table_names", "max_allowed_packet", b"max_allowed_packet", "max_connections", b"max_connections", "max_digest_length", b"max_digest_length", "max_execution_time", b"max_execution_time", "max_heap_table_size", b"max_heap_table_size", "max_prepared_stmt_count", b"max_prepared_stmt_count", "max_sp_recursion_depth", b"max_sp_recursion_depth", "mdb_offline_mode_disable_lag", b"mdb_offline_mode_disable_lag", "mdb_offline_mode_enable_lag", b"mdb_offline_mode_enable_lag", "mdb_preserve_binlog_bytes", b"mdb_preserve_binlog_bytes", "mdb_priority_choice_max_lag", b"mdb_priority_choice_max_lag", "net_read_timeout", b"net_read_timeout", "net_write_timeout", b"net_write_timeout", "optimizer_search_depth", b"optimizer_search_depth", "optimizer_switch", b"optimizer_switch", "query_cache_limit", b"query_cache_limit", "query_cache_size", b"query_cache_size", "query_cache_type", b"query_cache_type", "query_response_time_stats", b"query_response_time_stats", "range_optimizer_max_mem_size", b"range_optimizer_max_mem_size", "rpl_semi_sync_master_wait_for_slave_count", b"rpl_semi_sync_master_wait_for_slave_count", "show_compatibility_56", b"show_compatibility_56", "slave_parallel_type", b"slave_parallel_type", "slave_parallel_workers", b"slave_parallel_workers", "slow_query_log", b"slow_query_log", "slow_query_log_always_write_time", b"slow_query_log_always_write_time", "sort_buffer_size", b"sort_buffer_size", "sql_mode", b"sql_mode", "sync_binlog", b"sync_binlog", "table_definition_cache", b"table_definition_cache", "table_open_cache", b"table_open_cache", "table_open_cache_instances", b"table_open_cache_instances", "thread_cache_size", b"thread_cache_size", "thread_stack", b"thread_stack", "tmp_table_size", b"tmp_table_size", "transaction_isolation", b"transaction_isolation", "userstat", b"userstat", "wait_timeout", b"wait_timeout"]) -> None: ...

global___MysqlConfig5_7 = MysqlConfig5_7

@typing.final
class MysqlConfigSet5_7(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MysqlConfig5_7:
        """Effective settings for a MySQL 5.7 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MysqlConfig5_7:
        """User-defined settings for a MySQL 5.7 cluster."""

    @property
    def default_config(self) -> global___MysqlConfig5_7:
        """Default configuration for a MySQL 5.7 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MysqlConfig5_7 | None = ...,
        user_config: global___MysqlConfig5_7 | None = ...,
        default_config: global___MysqlConfig5_7 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MysqlConfigSet5_7 = MysqlConfigSet5_7



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/versions_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import version_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_version__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/mdb/clickhouse/v1/versions_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/clickhouse/v1/version.proto\"S\n\x13ListVersionsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"i\n\x14ListVersionsResponse\x12\x38\n\x07version\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.clickhouse.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\x01\n\x0fVersionsService\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.clickhouse.v1.ListVersionsRequest\x1a\x34.yandex.cloud.mdb.clickhouse.v1.ListVersionsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-clickhouse/v1/versionsBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.versions_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _VERSIONSSERVICE.methods_by_name['List']._options = None
  _VERSIONSSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-clickhouse/v1/versions'
  _globals['_LISTVERSIONSREQUEST']._serialized_start=196
  _globals['_LISTVERSIONSREQUEST']._serialized_end=279
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=281
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=386
  _globals['_VERSIONSSERVICE']._serialized_start=389
  _globals['_VERSIONSSERVICE']._serialized_end=563
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.cic.v1.common.lag_allocation_settings_pb2
import yandex.cloud.cic.v1.common.transceiver_type_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TrunkConnection(google.protobuf.message.Message):
    """A TrunkConnection resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Capacity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CapacityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TrunkConnection._Capacity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CAPACITY_UNSPECIFIED: TrunkConnection._Capacity.ValueType  # 0
        CAPACITY_50_MBPS: TrunkConnection._Capacity.ValueType  # 1
        CAPACITY_100_MBPS: TrunkConnection._Capacity.ValueType  # 2
        CAPACITY_200_MBPS: TrunkConnection._Capacity.ValueType  # 3
        CAPACITY_300_MBPS: TrunkConnection._Capacity.ValueType  # 4
        CAPACITY_400_MBPS: TrunkConnection._Capacity.ValueType  # 5
        CAPACITY_500_MBPS: TrunkConnection._Capacity.ValueType  # 6
        CAPACITY_1_GBPS: TrunkConnection._Capacity.ValueType  # 7
        CAPACITY_2_GBPS: TrunkConnection._Capacity.ValueType  # 8
        CAPACITY_3_GBPS: TrunkConnection._Capacity.ValueType  # 9
        CAPACITY_4_GBPS: TrunkConnection._Capacity.ValueType  # 10
        CAPACITY_5_GBPS: TrunkConnection._Capacity.ValueType  # 11
        CAPACITY_10_GBPS: TrunkConnection._Capacity.ValueType  # 12
        CAPACITY_20_GBPS: TrunkConnection._Capacity.ValueType  # 13
        CAPACITY_30_GBPS: TrunkConnection._Capacity.ValueType  # 14
        CAPACITY_40_GBPS: TrunkConnection._Capacity.ValueType  # 15
        CAPACITY_50_GBPS: TrunkConnection._Capacity.ValueType  # 16
        CAPACITY_100_GBPS: TrunkConnection._Capacity.ValueType  # 17

    class Capacity(_Capacity, metaclass=_CapacityEnumTypeWrapper): ...
    CAPACITY_UNSPECIFIED: TrunkConnection.Capacity.ValueType  # 0
    CAPACITY_50_MBPS: TrunkConnection.Capacity.ValueType  # 1
    CAPACITY_100_MBPS: TrunkConnection.Capacity.ValueType  # 2
    CAPACITY_200_MBPS: TrunkConnection.Capacity.ValueType  # 3
    CAPACITY_300_MBPS: TrunkConnection.Capacity.ValueType  # 4
    CAPACITY_400_MBPS: TrunkConnection.Capacity.ValueType  # 5
    CAPACITY_500_MBPS: TrunkConnection.Capacity.ValueType  # 6
    CAPACITY_1_GBPS: TrunkConnection.Capacity.ValueType  # 7
    CAPACITY_2_GBPS: TrunkConnection.Capacity.ValueType  # 8
    CAPACITY_3_GBPS: TrunkConnection.Capacity.ValueType  # 9
    CAPACITY_4_GBPS: TrunkConnection.Capacity.ValueType  # 10
    CAPACITY_5_GBPS: TrunkConnection.Capacity.ValueType  # 11
    CAPACITY_10_GBPS: TrunkConnection.Capacity.ValueType  # 12
    CAPACITY_20_GBPS: TrunkConnection.Capacity.ValueType  # 13
    CAPACITY_30_GBPS: TrunkConnection.Capacity.ValueType  # 14
    CAPACITY_40_GBPS: TrunkConnection.Capacity.ValueType  # 15
    CAPACITY_50_GBPS: TrunkConnection.Capacity.ValueType  # 16
    CAPACITY_100_GBPS: TrunkConnection.Capacity.ValueType  # 17

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class PartnerJointInfo(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on partner joint."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERVICE_KEY_FIELD_NUMBER: builtins.int
        PARTNER_ID_FIELD_NUMBER: builtins.int
        service_key: builtins.str
        """Reserved for future using;"""
        @property
        def partner_id(self) -> google.protobuf.wrappers_pb2.StringValue:
            """ID of partner that the trunkConnection is deployed on.
            Optional.
            If is not set scheduler selects it by himself.
            """

        def __init__(
            self,
            *,
            service_key: builtins.str = ...,
            partner_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["partner_id", b"partner_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["partner_id", b"partner_id", "service_key", b"service_key"]) -> None: ...

    @typing.final
    class SinglePortDirectJoint(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on single port."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSCEIVER_TYPE_FIELD_NUMBER: builtins.int
        PORT_NAME_FIELD_NUMBER: builtins.int
        ACCESS_DEVICE_NAME_FIELD_NUMBER: builtins.int
        transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType
        """Type of transceiver that the trunkConnection is deployed on."""
        access_device_name: builtins.str
        """Device name which is set in LLDP message."""
        @property
        def port_name(self) -> google.protobuf.wrappers_pb2.StringValue:
            """Name of port that the trunkConnection is deployed on."""

        def __init__(
            self,
            *,
            transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType = ...,
            port_name: google.protobuf.wrappers_pb2.StringValue | None = ...,
            access_device_name: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["port_name", b"port_name"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["access_device_name", b"access_device_name", "port_name", b"port_name", "transceiver_type", b"transceiver_type"]) -> None: ...

    @typing.final
    class LagDirectJoint(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on lag."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSCEIVER_TYPE_FIELD_NUMBER: builtins.int
        LAG_ALLOCATION_SETTINGS_FIELD_NUMBER: builtins.int
        ACCESS_DEVICE_NAME_FIELD_NUMBER: builtins.int
        transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType
        """Type of transceiver that the trunkConnection is deployed on."""
        access_device_name: builtins.str
        """Device name which is set in LLDP message."""
        @property
        def lag_allocation_settings(self) -> yandex.cloud.cic.v1.common.lag_allocation_settings_pb2.LagAllocationSettings:
            """LAG allocation settings that the trunkConnection is deployed on."""

        def __init__(
            self,
            *,
            transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType = ...,
            lag_allocation_settings: yandex.cloud.cic.v1.common.lag_allocation_settings_pb2.LagAllocationSettings | None = ...,
            access_device_name: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["lag_allocation_settings", b"lag_allocation_settings"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["access_device_name", b"access_device_name", "lag_allocation_settings", b"lag_allocation_settings", "transceiver_type", b"transceiver_type"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    SINGLE_PORT_DIRECT_JOINT_FIELD_NUMBER: builtins.int
    LAG_DIRECT_JOINT_FIELD_NUMBER: builtins.int
    PARTNER_JOINT_INFO_FIELD_NUMBER: builtins.int
    POINT_OF_PRESENCE_ID_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the trunkConnection."""
    name: builtins.str
    """Name of the trunkConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the trunkConnection. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the trunkConnection belongs to."""
    region_id: builtins.str
    """ID of the region that the trunkConnection belongs to."""
    capacity: global___TrunkConnection.Capacity.ValueType
    """Capacity of the trunkConnection"""
    @property
    def single_port_direct_joint(self) -> global___TrunkConnection.SinglePortDirectJoint: ...
    @property
    def lag_direct_joint(self) -> global___TrunkConnection.LagDirectJoint: ...
    @property
    def partner_joint_info(self) -> global___TrunkConnection.PartnerJointInfo: ...
    @property
    def point_of_presence_id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """ID of pointOfPresence that the trunkConnection is deployed on.
        Optional.
        If is not set scheduler selects it by himself.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        single_port_direct_joint: global___TrunkConnection.SinglePortDirectJoint | None = ...,
        lag_direct_joint: global___TrunkConnection.LagDirectJoint | None = ...,
        partner_joint_info: global___TrunkConnection.PartnerJointInfo | None = ...,
        point_of_presence_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        capacity: global___TrunkConnection.Capacity.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["joint", b"joint", "lag_direct_joint", b"lag_direct_joint", "partner_joint_info", b"partner_joint_info", "point_of_presence_id", b"point_of_presence_id", "single_port_direct_joint", b"single_port_direct_joint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["capacity", b"capacity", "description", b"description", "folder_id", b"folder_id", "id", b"id", "joint", b"joint", "labels", b"labels", "lag_direct_joint", b"lag_direct_joint", "name", b"name", "partner_joint_info", b"partner_joint_info", "point_of_presence_id", b"point_of_presence_id", "region_id", b"region_id", "single_port_direct_joint", b"single_port_direct_joint"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["joint", b"joint"]) -> typing.Literal["single_port_direct_joint", "lag_direct_joint", "partner_joint_info"] | None: ...

global___TrunkConnection = TrunkConnection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SQLServerConfig2017std(google.protobuf.message.Message):
    """SQL Server 2017 Standard edition supported configuration options are listed here.

    Detailed description for each set of options is available in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/server-configuration-options-sql-server?view=sql-server-2017).

    Any options that are not listed here are not supported.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_DEGREE_OF_PARALLELISM_FIELD_NUMBER: builtins.int
    COST_THRESHOLD_FOR_PARALLELISM_FIELD_NUMBER: builtins.int
    AUDIT_LEVEL_FIELD_NUMBER: builtins.int
    FILL_FACTOR_PERCENT_FIELD_NUMBER: builtins.int
    OPTIMIZE_FOR_AD_HOC_WORKLOADS_FIELD_NUMBER: builtins.int
    @property
    def max_degree_of_parallelism(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Limits the number of processors to use in parallel plan execution per task.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-max-degree-of-parallelism-server-configuration-option?view=sql-server-2017).
        """

    @property
    def cost_threshold_for_parallelism(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold at which SQL Server creates and runs parallel plans for queries.

        SQL Server creates and runs a parallel plan for a query only when the estimated cost to run a serial plan for the same query is higher than the value of the option.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-cost-threshold-for-parallelism-server-configuration-option?view=sql-server-2017).
        """

    @property
    def audit_level(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Describes how to configure login auditing to monitor SQL Server Database Engine login activity.

        Possible values:
        * 0 - do not log login attempts;
        * 1 - log only failed login attempts;
        * 2 - log only successful login attempts (not recommended);
        * 3 - log all login attempts (not recommended).

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/ssms/configure-login-auditing-sql-server-management-studio?view=sql-server-2017).
        """

    @property
    def fill_factor_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Manages the fill factor server configuration option.

        When an index is created or rebuilt, the fill factor determines the percentage of space on each index leaf-level page to be filled with data, reserving the rest as free space for future growth.

        Values 0 and 100 mean full page usage (no space reserved).

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-fill-factor-server-configuration-option?view=sql-server-2017).
        """

    @property
    def optimize_for_ad_hoc_workloads(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether plans should be cached only after second execution.

        Allows to avoid SQL cache bloat because of single-use plans.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/optimize-for-ad-hoc-workloads-server-configuration-option?view=sql-server-2017).
        """

    def __init__(
        self,
        *,
        max_degree_of_parallelism: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        cost_threshold_for_parallelism: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        audit_level: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        fill_factor_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        optimize_for_ad_hoc_workloads: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audit_level", b"audit_level", "cost_threshold_for_parallelism", b"cost_threshold_for_parallelism", "fill_factor_percent", b"fill_factor_percent", "max_degree_of_parallelism", b"max_degree_of_parallelism", "optimize_for_ad_hoc_workloads", b"optimize_for_ad_hoc_workloads"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_level", b"audit_level", "cost_threshold_for_parallelism", b"cost_threshold_for_parallelism", "fill_factor_percent", b"fill_factor_percent", "max_degree_of_parallelism", b"max_degree_of_parallelism", "optimize_for_ad_hoc_workloads", b"optimize_for_ad_hoc_workloads"]) -> None: ...

global___SQLServerConfig2017std = SQLServerConfig2017std

@typing.final
class SQLServerConfigSet2017std(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___SQLServerConfig2017std:
        """Effective settings for an SQL Server 2017 cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___SQLServerConfig2017std:
        """User-defined settings for an SQL Server 2017 cluster."""

    @property
    def default_config(self) -> global___SQLServerConfig2017std:
        """Default configuration for an SQL Server 2017 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___SQLServerConfig2017std | None = ...,
        user_config: global___SQLServerConfig2017std | None = ...,
        default_config: global___SQLServerConfig2017std | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___SQLServerConfigSet2017std = SQLServerConfigSet2017std

@typing.final
class SQLServerConfig2017ent(google.protobuf.message.Message):
    """SQL Server 2017 Enterprise edition supported configuration options are listed here.

    Detailed description for each set of options is available in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/server-configuration-options-sql-server?view=sql-server-2017).

    Any options that are not listed here are not supported.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_DEGREE_OF_PARALLELISM_FIELD_NUMBER: builtins.int
    COST_THRESHOLD_FOR_PARALLELISM_FIELD_NUMBER: builtins.int
    AUDIT_LEVEL_FIELD_NUMBER: builtins.int
    FILL_FACTOR_PERCENT_FIELD_NUMBER: builtins.int
    OPTIMIZE_FOR_AD_HOC_WORKLOADS_FIELD_NUMBER: builtins.int
    @property
    def max_degree_of_parallelism(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Limits the number of processors to use in parallel plan execution per task.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-max-degree-of-parallelism-server-configuration-option?view=sql-server-2017).
        """

    @property
    def cost_threshold_for_parallelism(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold at which SQL Server creates and runs parallel plans for queries.

        SQL Server creates and runs a parallel plan for a query only when the estimated cost to run a serial plan for the same query is higher than the value of the option.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-cost-threshold-for-parallelism-server-configuration-option?view=sql-server-2017).
        """

    @property
    def audit_level(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Describes how to configure login auditing to monitor SQL Server Database Engine login activity.

        Possible values:
        * 0 - do not log login attempts;
        * 1 - log only failed login attempts;
        * 2 - log only successful login attempts (not recommended);
        * 3 - log all login attempts (not recommended).

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/ssms/configure-login-auditing-sql-server-management-studio?view=sql-server-2017).
        """

    @property
    def fill_factor_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Manages the fill factor server configuration option.
        When an index is created or rebuilt, the fill factor determines the percentage of space on each index leaf-level page to be filled with data, reserving the rest as free space for future growth.

        Values 0 and 100 mean full page usage (no space reserved).

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/configure-the-fill-factor-server-configuration-option?view=sql-server-2017).
        """

    @property
    def optimize_for_ad_hoc_workloads(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether plans should be cached only after second execution.

        Allows to avoid SQL cache bloat because of single-use plans.

        See in-depth description in [SQL Server documentation](https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/optimize-for-ad-hoc-workloads-server-configuration-option?view=sql-server-2017).
        """

    def __init__(
        self,
        *,
        max_degree_of_parallelism: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        cost_threshold_for_parallelism: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        audit_level: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        fill_factor_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        optimize_for_ad_hoc_workloads: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audit_level", b"audit_level", "cost_threshold_for_parallelism", b"cost_threshold_for_parallelism", "fill_factor_percent", b"fill_factor_percent", "max_degree_of_parallelism", b"max_degree_of_parallelism", "optimize_for_ad_hoc_workloads", b"optimize_for_ad_hoc_workloads"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_level", b"audit_level", "cost_threshold_for_parallelism", b"cost_threshold_for_parallelism", "fill_factor_percent", b"fill_factor_percent", "max_degree_of_parallelism", b"max_degree_of_parallelism", "optimize_for_ad_hoc_workloads", b"optimize_for_ad_hoc_workloads"]) -> None: ...

global___SQLServerConfig2017ent = SQLServerConfig2017ent

@typing.final
class SQLServerConfigSet2017ent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___SQLServerConfig2017ent:
        """Effective settings for an SQL Server 2017 cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___SQLServerConfig2017ent:
        """User-defined settings for an SQL Server 2017 cluster."""

    @property
    def default_config(self) -> global___SQLServerConfig2017ent:
        """Default configuration for an SQL Server 2017 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___SQLServerConfig2017ent | None = ...,
        user_config: global___SQLServerConfig2017ent | None = ...,
        default_config: global___SQLServerConfig2017ent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___SQLServerConfigSet2017ent = SQLServerConfigSet2017ent



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.mdb.opensearch.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.opensearch.v1 import backup_service_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2


class BackupServiceStub(object):
    """A set of methods for managing backups.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.mdb.opensearch.v1.BackupService/Get',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.GetBackupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2.Backup.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.mdb.opensearch.v1.BackupService/List',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsResponse.FromString,
                )


class BackupServiceServicer(object):
    """A set of methods for managing backups.
    """

    def Get(self, request, context):
        """Returns the specified backup of an OpenSearch cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Returns the list of available backups for the specified OpenSearch cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BackupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.GetBackupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2.Backup.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.mdb.opensearch.v1.BackupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BackupService(object):
    """A set of methods for managing backups.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.mdb.opensearch.v1.BackupService/Get',
            yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.GetBackupRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2.Backup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.mdb.opensearch.v1.BackupService/List',
            yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__service__pb2.ListBackupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/bus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/serverless/eventrouter/v1/bus.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x03\n\x03\x42us\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12G\n\x06labels\x18\x07 \x03(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.Bus.LabelsEntry\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12\x42\n\x06status\x18\t \x01(\x0e\x32\x32.yandex.cloud.serverless.eventrouter.v1.Bus.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\x8a\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x04PERBZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.bus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\004PERBZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _BUS_LABELSENTRY._options = None
  _BUS_LABELSENTRY._serialized_options = b'8\001'
  _globals['_BUS']._serialized_start=126
  _globals['_BUS']._serialized_end=554
  _globals['_BUS_LABELSENTRY']._serialized_start=435
  _globals['_BUS_LABELSENTRY']._serialized_end=480
  _globals['_BUS_STATUS']._serialized_start=482
  _globals['_BUS_STATUS']._serialized_end=554
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HostType(google.protobuf.message.Message):
    """Represents host resources.
    Note: Platform can use hosts with different number of memory and cores.
    TODO: Do we need sockets here?
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique type identifier."""
    cores: builtins.int
    """Total number of cores available for instances."""
    memory: builtins.int
    """Ammount of memory available for instances."""
    disks: builtins.int
    """Number of local disks available for instances"""
    disk_size: builtins.int
    """Size of each local disk"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cores: builtins.int = ...,
        memory: builtins.int = ...,
        disks: builtins.int = ...,
        disk_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "disk_size", b"disk_size", "disks", b"disks", "id", b"id", "memory", b"memory"]) -> None: ...

global___HostType = HostType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource associated with the file."""
    path: builtins.str
    """File path."""
    size_bytes: builtins.int
    """File size in bytes."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        path: builtins.str = ...,
        size_bytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path", "project_id", b"project_id", "size_bytes", b"size_bytes"]) -> None: ...

global___FileMetadata = FileMetadata

@typing.final
class UploadFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    CHUNK_FIELD_NUMBER: builtins.int
    chunk: builtins.bytes
    """Byte chunk of the file to upload."""
    @property
    def metadata(self) -> global___FileMetadata:
        """Metadata of the file to upload."""

    def __init__(
        self,
        *,
        metadata: global___FileMetadata | None = ...,
        chunk: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunk", b"chunk", "message", b"message", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunk", b"chunk", "message", b"message", "metadata", b"metadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["message", b"message"]) -> typing.Literal["metadata", "chunk"] | None: ...

global___UploadFileRequest = UploadFileRequest

@typing.final
class UploadFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___FileMetadata:
        """Metadata of the uploaded file."""

    def __init__(
        self,
        *,
        metadata: global___FileMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata"]) -> None: ...

global___UploadFileResponse = UploadFileResponse

@typing.final
class DownloadFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to download the file from."""
    file_path: builtins.str
    """Path of the file to download."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "project_id", b"project_id"]) -> None: ...

global___DownloadFileRequest = DownloadFileRequest

@typing.final
class DownloadFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    CHUNK_FIELD_NUMBER: builtins.int
    chunk: builtins.bytes
    """Byte chunk of the downloaded file."""
    @property
    def metadata(self) -> global___FileMetadata:
        """Metadata of the downloaded file."""

    def __init__(
        self,
        *,
        metadata: global___FileMetadata | None = ...,
        chunk: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunk", b"chunk", "message", b"message", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunk", b"chunk", "message", b"message", "metadata", b"metadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["message", b"message"]) -> typing.Literal["metadata", "chunk"] | None: ...

global___DownloadFileResponse = DownloadFileResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.awscompatibility.access_key_pb2
import yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AccessKeyServiceStub:
    """A set of methods for managing access keys."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysResponse,
    ]
    """Retrieves the list of access keys for the specified service account."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.GetAccessKeyRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey,
    ]
    """Returns the specified access key.

    To get the list of available access keys, make a [List] request.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyResponse,
    ]
    """Creates an access key for the specified service account."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.UpdateAccessKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified access key."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.DeleteAccessKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified access key."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsResponse,
    ]
    """Retrieves the list of operations for the specified access key."""

class AccessKeyServiceAsyncStub:
    """A set of methods for managing access keys."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysResponse,
    ]
    """Retrieves the list of access keys for the specified service account."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.GetAccessKeyRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey,
    ]
    """Returns the specified access key.

    To get the list of available access keys, make a [List] request.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyResponse,
    ]
    """Creates an access key for the specified service account."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.UpdateAccessKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified access key."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.DeleteAccessKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified access key."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsRequest,
        yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsResponse,
    ]
    """Retrieves the list of operations for the specified access key."""

class AccessKeyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing access keys."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeysResponse]]:
        """Retrieves the list of access keys for the specified service account."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.GetAccessKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey, collections.abc.Awaitable[yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey]]:
        """Returns the specified access key.

        To get the list of available access keys, make a [List] request.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.CreateAccessKeyResponse]]:
        """Creates an access key for the specified service account."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.UpdateAccessKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified access key."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.DeleteAccessKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified access key."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2.ListAccessKeyOperationsResponse]]:
        """Retrieves the list of operations for the specified access key."""

def add_AccessKeyServiceServicer_to_server(servicer: AccessKeyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.containerregistry.v1.scanner_pb2
import yandex.cloud.containerregistry.v1.scanner_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ScannerServiceStub:
    """A set of methods for scanning Docker images."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Scan: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ScanRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes scanning of specified image."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.GetScanResultRequest,
        yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult,
    ]
    """Returns the specified ScanResult resource.

    To get the list of ScanResults for specified Image, make a [List] request.
    """

    GetLast: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.GetLastScanResultRequest,
        yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult,
    ]
    """Returns the last finished ScanResult for the specified Image."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsRequest,
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsResponse,
    ]
    """Retrieves the list of ScanResults for specified Image."""

    ListVulnerabilities: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesRequest,
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesResponse,
    ]
    """Retrieves the list of vulnerabilities found in particular scan."""

class ScannerServiceAsyncStub:
    """A set of methods for scanning Docker images."""

    Scan: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ScanRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes scanning of specified image."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.GetScanResultRequest,
        yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult,
    ]
    """Returns the specified ScanResult resource.

    To get the list of ScanResults for specified Image, make a [List] request.
    """

    GetLast: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.GetLastScanResultRequest,
        yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult,
    ]
    """Returns the last finished ScanResult for the specified Image."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsRequest,
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsResponse,
    ]
    """Retrieves the list of ScanResults for specified Image."""

    ListVulnerabilities: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesRequest,
        yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesResponse,
    ]
    """Retrieves the list of vulnerabilities found in particular scan."""

class ScannerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for scanning Docker images."""

    @abc.abstractmethod
    def Scan(
        self,
        request: yandex.cloud.containerregistry.v1.scanner_service_pb2.ScanRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Executes scanning of specified image."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.containerregistry.v1.scanner_service_pb2.GetScanResultRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult]]:
        """Returns the specified ScanResult resource.

        To get the list of ScanResults for specified Image, make a [List] request.
        """

    @abc.abstractmethod
    def GetLast(
        self,
        request: yandex.cloud.containerregistry.v1.scanner_service_pb2.GetLastScanResultRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult]]:
        """Returns the last finished ScanResult for the specified Image."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scanner_service_pb2.ListScanResultsResponse]]:
        """Retrieves the list of ScanResults for specified Image."""

    @abc.abstractmethod
    def ListVulnerabilities(
        self,
        request: yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scanner_service_pb2.ListVulnerabilitiesResponse]]:
        """Retrieves the list of vulnerabilities found in particular scan."""

def add_ScannerServiceServicer_to_server(servicer: ScannerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/marketplace/v1/helm_release_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.k8s.marketplace.v1 import helm_release_pb2 as yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/k8s/marketplace/v1/helm_release_service.proto\x12\x1fyandex.cloud.k8s.marketplace.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x32yandex/cloud/k8s/marketplace/v1/helm_release.proto\"q\n\x17ListHelmReleasesRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x18ListHelmReleasesResponse\x12\x43\n\rhelm_releases\x18\x01 \x03(\x0b\x32,.yandex.cloud.k8s.marketplace.v1.HelmRelease\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\")\n\x15GetHelmReleaseRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x95\x01\n\x19InstallHelmReleaseRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12product_version_id\x18\x02 \x01(\t\x12\x42\n\x0buser_values\x18\x03 \x03(\x0b\x32-.yandex.cloud.k8s.marketplace.v1.ValueWithKey\"e\n\x1aInstallHelmReleaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x17\n\x0fhelm_release_id\x18\x02 \x01(\t\x12\x1a\n\x12product_version_id\x18\x03 \x01(\t\"\x8c\x01\n\x18UpdateHelmReleaseRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12product_version_id\x18\x02 \x01(\t\x12\x42\n\x0buser_values\x18\x03 \x03(\x0b\x32-.yandex.cloud.k8s.marketplace.v1.ValueWithKey\"d\n\x19UpdateHelmReleaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x17\n\x0fhelm_release_id\x18\x02 \x01(\t\x12\x1a\n\x12product_version_id\x18\x03 \x01(\t\"/\n\x1bUninstallHelmReleaseRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x1cUninstallHelmReleaseMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0fhelm_release_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"X\n\x0cValueWithKey\x12\x11\n\x03key\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.yandex.cloud.k8s.marketplace.v1.Value\"\'\n\x05Value\x12\x15\n\x0btyped_value\x18\x01 \x01(\tH\x00\x42\x07\n\x05value2\xac\x08\n\x12HelmReleaseService\x12\xb5\x01\n\x04List\x12\x38.yandex.cloud.k8s.marketplace.v1.ListHelmReleasesRequest\x1a\x39.yandex.cloud.k8s.marketplace.v1.ListHelmReleasesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-kubernetes/marketplace/v1/helm-releases\x12\xaa\x01\n\x03Get\x12\x36.yandex.cloud.k8s.marketplace.v1.GetHelmReleaseRequest\x1a,.yandex.cloud.k8s.marketplace.v1.HelmRelease\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-kubernetes/marketplace/v1/helm-releases/{id}\x12\xda\x01\n\x07Install\x12:.yandex.cloud.k8s.marketplace.v1.InstallHelmReleaseRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*)\n\x1aInstallHelmReleaseMetadata\x12\x0bHelmRelease\x82\xd3\xe4\x93\x02=\"8/managed-kubernetes/marketplace/v1/helm-releases:install:\x01*\x12\xd4\x01\n\x06Update\x12\x39.yandex.cloud.k8s.marketplace.v1.UpdateHelmReleaseRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*(\n\x19UpdateHelmReleaseMetadata\x12\x0bHelmRelease\x82\xd3\xe4\x93\x02:25/managed-kubernetes/marketplace/v1/helm-releases/{id}:\x01*\x12\xfc\x01\n\tUninstall\x12<.yandex.cloud.k8s.marketplace.v1.UninstallHelmReleaseRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*5\n\x1cUninstallHelmReleaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N\"I/managed-kubernetes/marketplace/v1/helm-releases/uninstall/{id}:uninstall:\x01*Bz\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.marketplace.v1.helm_release_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplace'
  _LISTHELMRELEASESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTHELMRELEASESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _LISTHELMRELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTHELMRELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTHELMRELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTHELMRELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _GETHELMRELEASEREQUEST.fields_by_name['id']._options = None
  _GETHELMRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\350\3071\001'
  _INSTALLHELMRELEASEREQUEST.fields_by_name['cluster_id']._options = None
  _INSTALLHELMRELEASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _UPDATEHELMRELEASEREQUEST.fields_by_name['id']._options = None
  _UPDATEHELMRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\350\3071\001'
  _UNINSTALLHELMRELEASEREQUEST.fields_by_name['id']._options = None
  _UNINSTALLHELMRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\350\3071\001'
  _UNINSTALLHELMRELEASEMETADATA.fields_by_name['cluster_id']._options = None
  _UNINSTALLHELMRELEASEMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _UNINSTALLHELMRELEASEMETADATA.fields_by_name['helm_release_id']._options = None
  _UNINSTALLHELMRELEASEMETADATA.fields_by_name['helm_release_id']._serialized_options = b'\350\3071\001'
  _VALUEWITHKEY.fields_by_name['key']._options = None
  _VALUEWITHKEY.fields_by_name['key']._serialized_options = b'\350\3071\001'
  _HELMRELEASESERVICE.methods_by_name['List']._options = None
  _HELMRELEASESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/managed-kubernetes/marketplace/v1/helm-releases'
  _HELMRELEASESERVICE.methods_by_name['Get']._options = None
  _HELMRELEASESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0027\0225/managed-kubernetes/marketplace/v1/helm-releases/{id}'
  _HELMRELEASESERVICE.methods_by_name['Install']._options = None
  _HELMRELEASESERVICE.methods_by_name['Install']._serialized_options = b'\262\322*)\n\032InstallHelmReleaseMetadata\022\013HelmRelease\202\323\344\223\002=\"8/managed-kubernetes/marketplace/v1/helm-releases:install:\001*'
  _HELMRELEASESERVICE.methods_by_name['Update']._options = None
  _HELMRELEASESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateHelmReleaseMetadata\022\013HelmRelease\202\323\344\223\002:25/managed-kubernetes/marketplace/v1/helm-releases/{id}:\001*'
  _HELMRELEASESERVICE.methods_by_name['Uninstall']._options = None
  _HELMRELEASESERVICE.methods_by_name['Uninstall']._serialized_options = b'\262\322*5\n\034UninstallHelmReleaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002N\"I/managed-kubernetes/marketplace/v1/helm-releases/uninstall/{id}:uninstall:\001*'
  _globals['_LISTHELMRELEASESREQUEST']._serialized_start=282
  _globals['_LISTHELMRELEASESREQUEST']._serialized_end=395
  _globals['_LISTHELMRELEASESRESPONSE']._serialized_start=397
  _globals['_LISTHELMRELEASESRESPONSE']._serialized_end=517
  _globals['_GETHELMRELEASEREQUEST']._serialized_start=519
  _globals['_GETHELMRELEASEREQUEST']._serialized_end=560
  _globals['_INSTALLHELMRELEASEREQUEST']._serialized_start=563
  _globals['_INSTALLHELMRELEASEREQUEST']._serialized_end=712
  _globals['_INSTALLHELMRELEASEMETADATA']._serialized_start=714
  _globals['_INSTALLHELMRELEASEMETADATA']._serialized_end=815
  _globals['_UPDATEHELMRELEASEREQUEST']._serialized_start=818
  _globals['_UPDATEHELMRELEASEREQUEST']._serialized_end=958
  _globals['_UPDATEHELMRELEASEMETADATA']._serialized_start=960
  _globals['_UPDATEHELMRELEASEMETADATA']._serialized_end=1060
  _globals['_UNINSTALLHELMRELEASEREQUEST']._serialized_start=1062
  _globals['_UNINSTALLHELMRELEASEREQUEST']._serialized_end=1109
  _globals['_UNINSTALLHELMRELEASEMETADATA']._serialized_start=1111
  _globals['_UNINSTALLHELMRELEASEMETADATA']._serialized_end=1198
  _globals['_VALUEWITHKEY']._serialized_start=1200
  _globals['_VALUEWITHKEY']._serialized_end=1288
  _globals['_VALUE']._serialized_start=1290
  _globals['_VALUE']._serialized_end=1329
  _globals['_HELMRELEASESERVICE']._serialized_start=1332
  _globals['_HELMRELEASESERVICE']._serialized_end=2400
# @@protoc_insertion_point(module_scope)
